/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus;

import klaus.components.CloseTabComponent;
import klaus.components.ImageCache;
import klaus.views.BaseView;
import klaus.views.View;

import javax.swing.*;
import javax.swing.filechooser.FileSystemView;
import java.awt.*;
import java.io.File;

public class KlausWindow extends JFrame {
	@SuppressWarnings("unused")
	private KlausWindowMenuBar menu = null;
	
	/**
	 * Views are organized in a tabber. One frame can handle more than one view
	 * this way. This tabber is used for this functionality.
	 */
	private JTabbedPane tabber = null;
	
	/**
	 * Creates a new Klaus window.
	 *
	 */
	public KlausWindow(){	
		setLocationByPlatform(true);
        //This line would cause serious trouble on some JREs...
//		setLocationRelativeTo(null);
		setSize(1024, 786);
		setTitle(Information.name);
		menu = new KlausWindowMenuBar(this);
		
		tabber = new JTabbedPane();
		tabber.setTabLayoutPolicy(JTabbedPane.SCROLL_TAB_LAYOUT);
		add(tabber, BorderLayout.CENTER);
		
		setIconImage(ImageCache.getImage(new File("../../share/klaus/graphics/icon.png").getAbsolutePath()));
		
		setVisible(true);
	}
	
	public void addView(View view){
		tabber.addTab(null, view);
		tabber.setTabComponentAt(tabber.getTabCount() - 1, new CloseTabComponent(view.getDescription(), view));
		tabber.setSelectedIndex(tabber.getTabCount() - 1);
	}

	public boolean closeAllTabs() {
		System.out.println("TabManager:            Closing all tabs...");
		Component[] comps = tabber.getComponents();
		
		for(Component tab: comps){
			if(tab instanceof View){
				boolean test = ((View) tab).closeView();
				if(!test) return false;
			}
				
		}
		return true;
	}

	public void openBase() {
		JFileChooser chooser = new JFileChooser(FileSystemView.getFileSystemView().getHomeDirectory());
		int value = chooser.showOpenDialog(null);
		if(value == JFileChooser.APPROVE_OPTION){
			BaseView bv = new BaseView(this, chooser.getSelectedFile());
			addView(bv);
		}
	}
}
