/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus;

import klaus.dialogs.NewGameModel;
import klaus.dialogs.NewOfflineGameDialog;
import klaus.views.*;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.util.ResourceBundle;

/**
 * The menu bar for a Klaus Window
 * @author Stephan Hillebrand
 * @since 2009-03-10
 */
public class KlausWindowMenuBar extends JMenuBar implements ActionListener{
	
	private JMenuItem newgame, open, savePNG, settings, close;
	private JMenuItem onlineHelp, info, license, web;
	private JMenuItem loginToICS, playOnICS;
	private JCheckBoxMenuItem mute;

    private ResourceBundle resourceBundle = Resources.getMessages();
	
	private KlausWindow window;
	/**
	 * The menu bar constructor. This does not have to be public because it is only
	 * used inside the klaus package.
	 * @param window the window that uses this menu bar
	 */
	KlausWindowMenuBar(KlausWindow window){
		this.window = window;
		
		JMenu file = new JMenu(resourceBundle.getString("file"));
		add(file);
		
			newgame = new JMenuItem(resourceBundle.getString("new.game"));
			file.add(newgame);
			newgame.setAccelerator(KeyStroke.getKeyStroke(new Character('N'), InputEvent.CTRL_DOWN_MASK));
			newgame.addActionListener(this);
		
			open = new JMenuItem(resourceBundle.getString("open"));
			file.add(open);
			open.addActionListener(this);
				
			JMenu save = new JMenu(resourceBundle.getString("save"));
			file.add(save);
			
				savePNG = new JMenuItem(resourceBundle.getString("as.pgn.this.party"));
				savePNG.setEnabled(false);
				save.add(savePNG);
				
			file.add(new JSeparator());
			
			settings = new JMenuItem(resourceBundle.getString("preferences"));
			file.add(settings);
			settings.addActionListener(this);
		
			close = new JMenuItem(resourceBundle.getString("exit"));
			close.addActionListener(this);
			file.add(close);
		
		JMenu ics = new JMenu(resourceBundle.getString("internet.chess"));
		add(ics);
		
			loginToICS = new JMenuItem(resourceBundle.getString("connect.to.server"));
			ics.add(loginToICS);
			loginToICS.addActionListener(this);
		
			playOnICS = new JMenuItem(resourceBundle.getString("newgame"));
			ics.add(playOnICS);
			
			
		JMenu audio = new JMenu(resourceBundle.getString("sound"));
		add(audio);
		
			mute = new JCheckBoxMenuItem(resourceBundle.getString("mute"), false);
			mute.addActionListener(this);
			audio.add(mute);
		
		
			
		JMenu help = new JMenu(resourceBundle.getString("help"));
		add(help);
		
			onlineHelp = new JMenuItem(resourceBundle.getString("helpContent"));
			onlineHelp.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_F1, 0));
			help.add(onlineHelp);
			onlineHelp.addActionListener(this);
			
			web = new JMenuItem(resourceBundle.getString("klaus.on.the.internet"));
			help.add(web);
			
			help.add(new JSeparator());
			
			license = new JMenuItem(resourceBundle.getString("license"));
			help.add(license);
			license.addActionListener(this);
			
			info = new JMenuItem(resourceBundle.getString("about"));
			help.add(info);
			info.addActionListener(this);
			
		
		//Add the menu bar to the frame
		window.setJMenuBar(this);
	}

	public void actionPerformed(ActionEvent event) {
		if(event.getSource() == close){
			window.setVisible(false);
		}
		else if(event.getSource() == settings){
			window.addView(new ConfigurationView());
		}
		else if(event.getSource() == newgame){
			NewOfflineGameDialog dialog = new NewOfflineGameDialog(window, true);
			dialog.setVisible(true);
			//as the dialog is modal, we do not have to wait for it being closed
			
			//Get and handle the game model
			NewGameModel model = dialog.getModel();
			//Check if Abort was clicked
			if(!model.isStartNewGame()) return;
			
			
			PlayingView view = new PlayingView();
			
			
			
			if(model.getWhitePlayer()){
				view.getParty().setWhitePlayer(Settings.getSettings().getUsername());
			}else{
				view.getParty().setWhitePlayer(model.getWhiteEngineName());
				view.setWhiteEngineName(model.getWhiteEngineName());
			}
			
			if(model.getBlackPlayer()){
				view.getParty().setBlackPlayer(Settings.getSettings().getUsername());
			}else{
				view.getParty().setBlackPlayer(model.getBlackEngineName());
				view.setBlackEngineName(model.getBlackEngineName());
			}
			
			view.setGameModel(model);
			
			window.addView(view);
			
		}
		
		else if(event.getSource() == open){
			window.openBase();
		}
		
		else if(event.getSource() == info){
			window.addView(new InfoView());
		}
		else if(event.getSource() == license){
			window.addView(new GPLView());
		}
		else if(event.getSource() == onlineHelp){
			window.addView(new HelpView());
		}
		
		else if(event.getSource() == mute){
			Settings.getSettings().setPlaySounds(!mute.isSelected());
		}
		
		else if(event.getSource() == loginToICS){
			//Create a new ICS login view that will handle the rest of this login action
			window.addView(new ICSLoginView(window));
		}
	}
}
