/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.backend;

import klaus.chess.Move;
import klaus.chess.Position;
import klaus.chess.Result;
import klaus.chess.party.Party;

import java.util.Vector;


/**
 * This is a default backend implementing basic actions (setActive/setInactive)
 * and ignoring most of the input. Other backends should extend this instead of implementing
 * ChessBackend.
 * @author Stephan Hillebrand
 * @since 2009-03-13
 */
public class NullBackend implements ChessBackend {
	
	
	protected long whiteTime = 300000, blackTime = 300000;
	protected boolean active = true;
	@SuppressWarnings("unused")
	public boolean addMove(Move move) {
		return active;
	}
	public void setActive() {
		active = true;
	}

	public void setInactive() {
		active = false;
	}
	@SuppressWarnings("unused")
	public void setPosition(Position position) {}
	
	
	private Vector<MoveListener> moveListeners = new Vector<MoveListener>();
	public void addMoveListener(MoveListener listener){
		moveListeners.add(listener);
	}
	public void removeMoveListener(MoveListener listener){
		moveListeners.remove(listener);
	}
	public void fireMoveListeners(Move move){
		for(MoveListener listener: moveListeners)
			listener.moveDone(move);
	}
	
	
	private Vector<ResultListener> resultListeners = new Vector<ResultListener>();
	public void addResultListener(ResultListener listener) {
		resultListeners.add(listener);
	}
	public void removeResultListener(ResultListener listener) {
		resultListeners.add(listener);
	}

	public void fireResultListeners(Result result){
		System.out.println("ResultListeners:       fired! ("+this+")");
		for(ResultListener listener: resultListeners){
			System.out.println("ResultListeners:       firing "+listener);
			listener.result(result);
		}
	}
	public void unload() {}
	
	public long getBlackTime() {
		return blackTime;
	}
	public long getWhiteTime() {
		return whiteTime;
	}
	public Party getParty() {
		return new Party();
	}
	public Position getPosition(){
		return new Position();
	}
	
	public boolean isGameRunning() {
		return false;
	}
}
