/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.components;

import klaus.Resources;
import klaus.backend.ScrollingBackend;
import klaus.views.AnalyzeView;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.ResourceBundle;

public class AnalyzingToolbar extends JToolBar implements ActionListener {
	private JButton first, last, previous, next;
	private AnalyzeView view;
	
	public AnalyzingToolbar(AnalyzeView view){
        ResourceBundle resourceBundle = Resources.getMessages();
        
		this.view = view;
		first = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/first.png").getAbsolutePath())));
		first.setToolTipText(resourceBundle.getString("go.to.first.move"));
        add(first);
		first.addActionListener(this);
		
		previous  = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/previous.png").getAbsolutePath())));
		previous.setToolTipText(resourceBundle.getString("previous.move"));
        add(previous);
		previous.addActionListener(this);
		
		next = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/next.png").getAbsolutePath())));
		next.setToolTipText(resourceBundle.getString("next.move"));
        add(next);
		next.addActionListener(this);
		
		last = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/last.png").getAbsolutePath())));
		last.setToolTipText(resourceBundle.getString("go.to.last.move"));
        add(last);
		last.addActionListener(this);
	}

	public void actionPerformed(ActionEvent e) {
		ScrollingBackend backend = null;
		if(view.getBackend() instanceof ScrollingBackend)
			backend = (ScrollingBackend) view.getBackend();
		else backend = new ScrollingBackend(){
			public void goToFirst() {}
			public void goToLast() {}
			public void goToNext() {}
			public void goToPrevious() {}	
		};
		
		if(e.getSource() == first) backend.goToFirst();
		if(e.getSource() == previous) backend.goToPrevious();
		if(e.getSource() == next) backend.goToNext();
		if(e.getSource() == last) backend.goToLast();
	}
}
