/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.components;

import klaus.Settings;
import klaus.backend.ChessBackend;

import javax.swing.*;
import java.awt.*;

public class ChessClock extends JPanel{
	
	ChessBackend backend = null;
	private boolean running = true;

	
//	int wTime = 3645;
//	int bTime = 4567;
	
	public ChessClock(ChessBackend backend){
		this.backend = backend;
		setMinimumSize(new Dimension(300,100));
		new SyncThread().start();
	}
	
	public void stop(){
		running = false;
	}
	
	@Override
	protected void paintComponent(Graphics g) {
		int bTime = (int)(backend.getBlackTime() / 1000);
		int wTime = (int)(backend.getWhiteTime() / 1000);
//		System.out.println("Times are "+wTime+" and "+bTime+" in seconds");
		if(Settings.getSettings().getClockMode().equals("DIGITAL")){
			g.setColor(Color.BLACK);
			g.fillRect(0, 0, getWidth(), getHeight());
			
			g.setColor(Color.WHITE);
			
			double areaWidth = getWidth() * 0.4;
			double areaHeight = getHeight() * 0.9;
			
			//Find out wheter the bottleneck is the height or the width of
			//the area
			if(areaWidth / 7 > areaHeight / 2){
				areaWidth = areaHeight * 3.5;
			}else{
				areaHeight = areaWidth  / 3.5;
			}
			
			g.setColor(Color.GRAY);
			g.fillRect((int)(getWidth()*0.05), (int)(getHeight()*0.05), (int)areaWidth, (int)areaHeight);
			g.fillRect((int)(getWidth()*0.95 - areaWidth), (int)(getHeight()*0.05), (int)areaWidth, (int)areaHeight);
			
			int xstart = (int)(getWidth()*0.05);
			int ystart = (int)(getHeight()*0.05);
			int width = (int)(areaWidth / 7);
			int height = (int)(areaHeight);
			
			int hours = wTime / 3600;
			wTime = wTime % 3600;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+hours+".png"),
					xstart, ystart, width, height, null);
			
			g.drawImage(ImageCache.getImage("./graphics/clock/doubledot.png"),
					xstart+width, ystart, width, height, null);
			
			
			int tenmins = wTime / 600;
			wTime = wTime  % 600;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+tenmins+".png"),
					xstart+2*width, ystart, width, height, null);
			
			int mins = wTime / 60;
			wTime = wTime % 60;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+mins+".png"),
					xstart+3*width, ystart, width, height, null);
			
			g.drawImage(ImageCache.getImage("./graphics/clock/dot.png"),
					xstart+4*width, ystart, width, height, null);
			
			int tenSecs = wTime / 10;
			wTime = wTime % 10;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+tenSecs+".png"),
					xstart+5*width, ystart, width, height, null);
			
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+wTime+".png"),
					xstart+6*width, ystart, width, height, null);
			
			xstart = (int)(getWidth()*0.95 - areaWidth);
			ystart = (int)(getHeight()*0.05);
			
			hours = bTime / 3600;
			bTime = bTime % 3600;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+hours+".png"),
					xstart, ystart, width, height, null);
			
			g.drawImage(ImageCache.getImage("./graphics/clock/doubledot.png"),
					xstart+width, ystart, width, height, null);
			
			
			tenmins = bTime / 600;
			bTime = bTime  % 600;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+tenmins+".png"),
					xstart+2*width, ystart, width, height, null);
			
			mins = bTime / 60;
			bTime = bTime % 60;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+mins+".png"),
					xstart+3*width, ystart, width, height, null);
			
			g.drawImage(ImageCache.getImage("./graphics/clock/dot.png"),
					xstart+4*width, ystart, width, height, null);
			
			tenSecs = bTime / 10;
			bTime = bTime % 10;
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+tenSecs+".png"),
					xstart+5*width, ystart, width, height, null);
			
			g.drawImage(ImageCache.getImage("./graphics/clock/digit"+bTime+".png"),
					xstart+6*width, ystart, width, height, null);
		}
	}
	
	private class SyncThread extends Thread {
		@Override
		public void run() {
			while(running){
				repaint();
				
				try{
					Thread.sleep(100);
				}catch(Exception e){}
			}
		}
	}
	
}
