/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.components;

import free.freechess.FreechessConnection;
import klaus.Resources;

import javax.swing.*;
import java.awt.*;
import java.text.MessageFormat;import java.util.HashMap;

public class ICSChannelChatMainPanel extends JPanel {
	
	private JTabbedPane tabber;
	
	private ICSChannelChatPanel shouts, cshouts;
	private HashMap<Integer, ICSChannelChatPanel> channels = new HashMap<Integer, ICSChannelChatPanel>();
	
	private FreechessConnection connection;
	
	public ICSChannelChatMainPanel(FreechessConnection connection){
		
		this.connection = connection;
		
		//This main panel contains a tabbed pane containing
		//one panel for each channel, one for shouts and for cshouts
		
		setLayout(new BorderLayout());
		
		tabber = new JTabbedPane();
		
		shouts = new ICSChannelChatPanel(connection, ICSChannelChatPanel.SHOUT_CHANNEL);
		cshouts = new ICSChannelChatPanel(connection, ICSChannelChatPanel.CSHOUT_CHANNEL);
		
		tabber.addTab(Resources.getMessages().getString("shouts"), shouts);
		tabber.addTab(Resources.getMessages().getString("cshouts"), cshouts);
		
		
		add(tabber, BorderLayout.CENTER);
	}
	
	/**
	 * Add a message
	 * @param ch - the channel, ICSChannelChatPanel.SHOUT_CHANNEL or 
	 * ICSChannelChatPanel.CSHOUT_CHANNEL
	 * @param user the user
	 * @param data the user's titles
	 * @param message the message
	 */
	public void addMessage(int ch, String user, String data, String message){
		if(ch == ICSChannelChatPanel.SHOUT_CHANNEL){
			shouts.addMessage(user, data, message);
		}
		else if (ch == ICSChannelChatPanel.CSHOUT_CHANNEL){
			cshouts.addMessage(user, data, message);
		}
		else if(ch >= 0){
			ICSChannelChatPanel chat = channels.get(ch);
			if(chat == null){
				//Chat window does not exist, create it first
				chat = new ICSChannelChatPanel(connection, ch);
				tabber.addTab(MessageFormat.format(Resources.getMessages().getString("channel.{0}"), ch), chat);
				channels.put(ch, chat);
			}
			
			chat.addMessage(user, data, message);
		}
	}
}
