/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.components;

import free.freechess.FreechessConnection;
import klaus.Resources;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

public class ICSChannelChatPanel extends JPanel {
	/**
	 * The channel ID
	 */
	private int chid;
	
	/**
	 * The ICS connection
	 */
	
	private FreechessConnection connection;
	
	/**
	 * Determines this is the window for shouts instead
	 * of a normal channel
	 */
	public static final int SHOUT_CHANNEL = -1;
	
	/**
	 * Window for CSHOUTs
	 */
	public static final int CSHOUT_CHANNEL = -2;
	
	/**
	 * text area for output
	 */
	private JTextArea out;
	
	/**
	 * Create a new ICS channel chat panel
	 * @param connection the freechess connection used to send data to the net
	 * @param chid any channel id or SHOUT_CHANNEL if this should be a shout panel.
	 * The id is needed in order to send chat messages / shouts.
	 */
	public ICSChannelChatPanel(FreechessConnection connection, int chid){
		
		this.connection = connection;
		
		out = new JTextArea();
		JScrollPane p = new JScrollPane();
		
		p.add(out);
		p.getViewport().add(out);
		
		setLayout(new BorderLayout());
		add(p, BorderLayout.CENTER);
		
		out.setEditable(false);
		out.setFont(new Font(Font.MONOSPACED, Font.PLAIN, out.getFont().getSize()));
		
		JPanel enter = new JPanel();
		enter.setLayout(new BorderLayout());
		
		final JTextField input = new JTextField();
		input.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				sendmsg(input.getText());
			}
		});
		enter.add(input, BorderLayout.CENTER);
		
		JButton send = new JButton(Resources.getMessages().getString("execute"));
		enter.add(send, BorderLayout.EAST);
		send.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				sendmsg(input.getText());
			}
		});
		
		add(enter, BorderLayout.SOUTH);
	}
	
	/**
	 * Send a command to the server
	 * @param text - the command to send
	 */
	private void sendmsg(String text) {
		if(chid == SHOUT_CHANNEL){
			connection.sendCommand("shout "+text);
		}
		else if(chid == CSHOUT_CHANNEL){
			connection.sendCommand("cshout "+text);
		}
		else {
			connection.sendCommand("tell "+chid+" "+text);
		}
	}
	
	/**
	 * print a chat message to output
	 * @param user - who said it?
	 * @param data the user's titles (like SR)
	 * @param message the message
	 */
	public void addMessage(String user, String data, String message){
		String uname = user+" "+data+": ";
		while(uname.length() < 25) uname += " ";
		out.append(uname + message + "\n");
	}
}
