/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.components;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.util.HashMap;

/**
 * Caches the images used by the layout(s).
 * @author Stephan Hillebrand
 *
 */
public class ImageCache {
	private static HashMap<String, BufferedImage> map = new HashMap<String, BufferedImage>();
	
	public static BufferedImage getImage(String layoutName, String imgName){
		//Per default, only png is supported. Other formats have to be read
		//using getImage(String);
		String absoluteFileName = new File("../../share/klaus/layouts/"+layoutName+"/"+imgName+".png").getAbsolutePath();
		
		return getImage(absoluteFileName);
	}
	
	public static BufferedImage getImage(String absoluteFileName){

		BufferedImage image = map.get(absoluteFileName);
		
		if(image == null){
			//Load the image
			try{
				image = ImageIO.read(new File(absoluteFileName));
				
			}catch(Exception e){
				System.err.println("Failed to load "+absoluteFileName);
				return null;
			}
			
			map.put(absoluteFileName, image);
			
		}
		
		return image;
	}
}
