/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.components;

import klaus.Resources;
import klaus.backend.ScrollingBackend;
import klaus.views.PlayingView;

import javax.swing.*;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;

public class PlayingToolbar extends JToolBar implements ActionListener{
	
	private JButton draw, resign;
	private JButton engineStartStop;
	private JToggleButton rotateBoard;
	private JButton first, last, previous, next;
	private PlayingView view;
	
	public PlayingToolbar(PlayingView view){ 
		this.view = view;
		draw = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/draw.png").getAbsolutePath())));
		add(draw);
		draw.setToolTipText(Resources.getMessages().getString("offer.or.accept.draw"));
		
		resign = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/resign.png").getAbsolutePath())));
		add(resign);
		resign.setToolTipText(Resources.getMessages().getString("resign.tooltip"));
		
		add(new Separator());
		
		engineStartStop = new JButton(new ImageIcon(
				ImageCache.getImage(new File("./graphics/playing/engine-startstop.png").getAbsolutePath())));
		add(engineStartStop);
		engineStartStop.setToolTipText(Resources.getMessages().getString("start.stop.engine"));
		engineStartStop.addActionListener(this);
		
		rotateBoard = new JToggleButton(new ImageIcon(ImageCache.getImage(
				new File("./graphics/playing/rotate-board.png").getAbsolutePath())), false);
		rotateBoard.setToolTipText("Rotate board");
		add(rotateBoard);
		rotateBoard.addActionListener(this);
		
		//Use JToolBar.Separator here instead of JSeparator!
		add(new Separator());
		
		first = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/first.png").getAbsolutePath())));
		add(first);
		first.addActionListener(this);
		
		previous  = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/previous.png").getAbsolutePath())));
		add(previous);
		previous.addActionListener(this);
		
		next = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/next.png").getAbsolutePath())));
		add(next);
		next.addActionListener(this);
		
		last = new JButton(new ImageIcon(ImageCache.getImage(new File("./graphics/playing/last.png").getAbsolutePath())));
		add(last);
		last.addActionListener(this);
	}

	public void actionPerformed(ActionEvent e) {
		ScrollingBackend backend = null;
		if(view.getBackend() instanceof ScrollingBackend)
			backend = (ScrollingBackend) view.getBackend();
		else backend = new ScrollingBackend(){
			public void goToFirst() {}
			public void goToLast() {}
			public void goToNext() {}
			public void goToPrevious() {}	
		};
		
		if(e.getSource() == first) backend.goToFirst();
		if(e.getSource() == previous) backend.goToPrevious();
		if(e.getSource() == next) backend.goToNext();
		if(e.getSource() == last) backend.goToLast();
		
		if(e.getSource() == engineStartStop){
			if(view.getBackend().isEngineThinking()){
				view.getBackend().startCalculation();
			}else{
				view.getBackend().forceMove();
			}
		}
		
		if(e.getSource() == rotateBoard){
			// Rotate chess board
			view.getChessBoard().setTurned(rotateBoard.isSelected());
		}
	}
	
	
}
