/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.cs;

/**
 * A ICS (Internet Chess Server, e. g. FICS) profile storing IP, port,
 * username and password (if given by the user)
 * @author Stephan Hillebrand
 * @since 2009
 */
public class ICSProfile {
	private String username = null;
	private boolean registered = false;
	
	/**
	 * The userr's password, null means the password is not given and
	 * has to be requested each login
	 */
	private String password = null;
	
	/**
	 * The IP address for this ICS
	 */
	private String ip;
	
	/**
	 * The port, 5000 is default for FICS and FICS-based servers
	 */
	private int port = 5000;
	
	public ICSProfile(){}

	public String getUsername() {
		return username;
	}

	public void setUsername(String username) {
		this.username = username;
	}

	public boolean isRegistered() {
		return registered;
	}

	public void setRegistered(boolean registered) {
		this.registered = registered;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public int getPort() {
		return port;
	}

	public void setPort(int port) {
		this.port = port;
	}
}
