/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.cs;

import free.freechess.FreechessConnection;
import klaus.components.ICSChannelChatPanel;
import klaus.views.ICSView;

/**
 * FICS connection for Klaus, based on Jin implementation.
 * This class extends the jin free.freechess.FreechessConnection class
 * and dispatches events to where they belong.
 * @author Stephan Hillebrand
 * @since 2009-05-13
 */
public class KlausFreechessConnection extends FreechessConnection {
	private ICSView parent;
	/**
	 * Creates a new Klaus freechess connection.
	 * @param uname the user name
	 * @param pwd the password
	 * @param view the ICSView associated to this connection
	 */
	public KlausFreechessConnection(String uname, String pwd, ICSView view){
		super(uname, pwd, null);
		parent = view;
	}
	
	@Override
	protected void handleMessage(Object lineObj) {
		if(lineObj instanceof String)
			parent.dispatchAnything((String) lineObj);
		super.handleMessage(lineObj);
	}
	
	@Override
	protected boolean processChannelTell(String username, String titles,
			int channelNumber, String message) {
		parent.dispatchChannelTell(username, titles, channelNumber, message);
		return true;
	}
	
	@Override
	protected boolean processCShout(String username, String titles,
			String message) {
		parent.dispatchChannelTell(username, titles, ICSChannelChatPanel.CSHOUT_CHANNEL, message);
		return true;
	}
	
	@Override
	protected boolean processShout(String username, String titles,
			String message) {
		parent.dispatchChannelTell(username, titles, ICSChannelChatPanel.SHOUT_CHANNEL, message);
		return true;
	}

	
//	process
}