/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.dialogs;

import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import klaus.engine.EngineData;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.ResourceBundle;

public class EngineDialog extends JDialog {
    private JPanel contentPane;
    private JButton buttonOK;
    private JButton buttonCancel;
    private JComboBox engineTypeBox;
    private JTextField cmdLineBox;
    private JButton selectExecutable;
    private JButton engineSettingsButton;
    private JLabel engineTypeLabel;
    private JLabel cmdLineLabel;
    private JTextField engineName;
    private JPanel buttonPanel;
    private JPanel inputPanel;

    private int returnValue = 1;

    public EngineDialog() {
        setContentPane(contentPane);
        setModal(true);
        getRootPane().setDefaultButton(buttonOK);

        buttonOK.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onOK();
            }
        });

        buttonCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onCancel();
            }
        });

// call onCancel() when cross is clicked
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                onCancel();
            }
        });

// call onCancel() on ESCAPE
        contentPane.registerKeyboardAction(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                onCancel();
            }
        }, KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
        final JDialog parent = this;
        selectExecutable.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                JFileChooser ch = new JFileChooser();


                int i = ch.showOpenDialog(parent);
                if (i == JOptionPane.OK_OPTION) {
                    System.out.println("OK clicked");
                    //Put the path in "", else spaces will confuse the system and lead to mean errors.
                    cmdLineBox.setText("\"" + ch.getSelectedFile().getAbsolutePath() + "\"");
                } else
                    System.out.println("Cancelled!");
            }
        });
    }

    private void onOK() {
        returnValue = 0;
        dispose();
    }

    private void onCancel() {
        returnValue = 1;
        dispose();
    }

    public static void main(String[] args) {
        EngineDialog dialog = new EngineDialog();
        dialog.pack();
        dialog.setVisible(true);
        System.exit(0);
    }

    public static EngineData showDlg() {
        return showDlg(new EngineData(EngineData.ENGINE_PROTOCOL_WINBOARD_XBOARD, "", ""));
    }

    public static EngineData showDlg(EngineData edit) {
        EngineDialog dlg = new EngineDialog();
        dlg.pack();
        //This is a quick fix to prevent the window popping up on the top left edge of the screen.
        //TODO Fix this more elegant...
        dlg.setBounds(200, 200, dlg.getWidth(), dlg.getHeight());
        dlg.engineName.setText(edit.getName());
        dlg.cmdLineBox.setText(edit.getExecutable());
        int i = edit.getEngineType();
        //Determine engine type
        if (i == EngineData.ENGINE_PROTOCOL_UCI) dlg.engineTypeBox.setSelectedIndex(1);
        else if (i == EngineData.ENGINE_PROTOCOL_WINBOARD_XBOARD) dlg.engineTypeBox.setSelectedIndex(0);

        //SHow modal dialog
        dlg.setModal(true);
        dlg.setVisible(true);

        //Check if OK or cancel was clicked
        if (dlg.returnValue != 0) return EngineData.NO_ENGINE;

        //After dialog being closed, generate and return new engine data
        i = EngineData.ENGINE_PROTOCOL_UCI;
        if (dlg.engineTypeBox.getSelectedIndex() == 0) i = EngineData.ENGINE_PROTOCOL_WINBOARD_XBOARD;
        return new EngineData(i, dlg.cmdLineBox.getText(), dlg.engineName.getText());

    }

    {
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
        $$$setupUI$$$();
    }

    /**
     * Method generated by IntelliJ IDEA GUI Designer
     * >>> IMPORTANT!! <<<
     * DO NOT edit this method OR call it in your code!
     *
     * @noinspection ALL
     */
    private void $$$setupUI$$$() {
        contentPane = new JPanel();
        contentPane.setLayout(new FormLayout("fill:d:grow,left:4dlu:noGrow,fill:max(d;4px):noGrow,left:4dlu:noGrow,fill:max(d;4px):noGrow", "center:d:grow,top:4dlu:noGrow,center:max(d;4px):noGrow,top:4dlu:noGrow,center:max(d;4px):noGrow,top:4dlu:noGrow,center:max(d;4px):noGrow"));
        buttonPanel = new JPanel();
        buttonPanel.setLayout(new FormLayout("fill:d:grow", ""));
        CellConstraints cc = new CellConstraints();
        contentPane.add(buttonPanel, cc.xy(1, 7));
        inputPanel = new JPanel();
        inputPanel.setLayout(new FormLayout("fill:max(d;4px):noGrow,left:4dlu:noGrow,fill:d:grow,left:4dlu:noGrow,fill:max(d;4px):noGrow", "center:max(d;4px):noGrow,top:4dlu:noGrow,center:max(d;4px):noGrow,top:4dlu:noGrow,center:max(d;4px):noGrow,top:4dlu:noGrow,center:d:grow"));
        contentPane.add(inputPanel, cc.xywh(1, 1, 1, 2));
        engineTypeLabel = new JLabel();
        this.$$$loadLabelText$$$(engineTypeLabel, ResourceBundle.getBundle("share/klaus/i18n/Messages").getString("engine.type"));
        inputPanel.add(engineTypeLabel, cc.xy(1, 3));
        engineTypeBox = new JComboBox();
        engineTypeBox.setEditable(false);
        engineTypeBox.setEnabled(true);
        final DefaultComboBoxModel defaultComboBoxModel1 = new DefaultComboBoxModel();
        defaultComboBoxModel1.addElement("XBoard/Winboard");
        defaultComboBoxModel1.addElement("UCI");
        engineTypeBox.setModel(defaultComboBoxModel1);
        inputPanel.add(engineTypeBox, cc.xy(3, 3));
        cmdLineLabel = new JLabel();
        this.$$$loadLabelText$$$(cmdLineLabel, ResourceBundle.getBundle("share/klaus/i18n/Messages").getString("engine.command"));
        inputPanel.add(cmdLineLabel, cc.xy(1, 5));
        cmdLineBox = new JTextField();
        inputPanel.add(cmdLineBox, cc.xy(3, 5, CellConstraints.FILL, CellConstraints.DEFAULT));
        selectExecutable = new JButton();
        selectExecutable.setText("...");
        inputPanel.add(selectExecutable, cc.xy(5, 5));
        final JLabel label1 = new JLabel();
        this.$$$loadLabelText$$$(label1, ResourceBundle.getBundle("share/klaus/i18n/Messages").getString("engine.name"));
        inputPanel.add(label1, cc.xy(1, 1));
        engineName = new JTextField();
        engineName.setText(ResourceBundle.getBundle("share/klaus/i18n/Messages").getString("noname.engine"));
        inputPanel.add(engineName, cc.xy(3, 1, CellConstraints.FILL, CellConstraints.DEFAULT));
        final JPanel panel1 = new JPanel();
        panel1.setLayout(new FlowLayout(FlowLayout.CENTER, 5, 5));
        contentPane.add(panel1, cc.xy(1, 5));
        engineSettingsButton = new JButton();
        this.$$$loadButtonText$$$(engineSettingsButton, ResourceBundle.getBundle("share/klaus/i18n/Messages").getString("engine.settings"));
        panel1.add(engineSettingsButton);
        buttonOK = new JButton();
        this.$$$loadButtonText$$$(buttonOK, ResourceBundle.getBundle("share/klaus/i18n/Messages").getString("ok"));
        panel1.add(buttonOK);
        buttonCancel = new JButton();
        this.$$$loadButtonText$$$(buttonCancel, ResourceBundle.getBundle("share/klaus/i18n/Messages").getString("cancel"));
        panel1.add(buttonCancel);
    }

    /**
     * @noinspection ALL
     */
    private void $$$loadLabelText$$$(JLabel component, String text) {
        StringBuffer result = new StringBuffer();
        boolean haveMnemonic = false;
        char mnemonic = '\0';
        int mnemonicIndex = -1;
        for (int i = 0; i < text.length(); i++) {
            if (text.charAt(i) == '&') {
                i++;
                if (i == text.length()) break;
                if (!haveMnemonic && text.charAt(i) != '&') {
                    haveMnemonic = true;
                    mnemonic = text.charAt(i);
                    mnemonicIndex = result.length();
                }
            }
            result.append(text.charAt(i));
        }
        component.setText(result.toString());
        if (haveMnemonic) {
            component.setDisplayedMnemonic(mnemonic);
            component.setDisplayedMnemonicIndex(mnemonicIndex);
        }
    }

    /**
     * @noinspection ALL
     */
    private void $$$loadButtonText$$$(AbstractButton component, String text) {
        StringBuffer result = new StringBuffer();
        boolean haveMnemonic = false;
        char mnemonic = '\0';
        int mnemonicIndex = -1;
        for (int i = 0; i < text.length(); i++) {
            if (text.charAt(i) == '&') {
                i++;
                if (i == text.length()) break;
                if (!haveMnemonic && text.charAt(i) != '&') {
                    haveMnemonic = true;
                    mnemonic = text.charAt(i);
                    mnemonicIndex = result.length();
                }
            }
            result.append(text.charAt(i));
        }
        component.setText(result.toString());
        if (haveMnemonic) {
            component.setMnemonic(mnemonic);
            component.setDisplayedMnemonicIndex(mnemonicIndex);
        }
    }

    /**
     * @noinspection ALL
     */
    public JComponent $$$getRootComponent$$$() {
        return contentPane;
    }
}
