/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.dialogs;

import klaus.Resources;
import myutils.ListFile;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.HashMap;
import java.util.Locale;
import java.util.Random;

public class Jokes {
	HashMap<JokeCategory, String[ ]> list = new HashMap<JokeCategory, String[]>();
	
	private static Jokes jokes = new Jokes();
	
	public static Jokes getJokes(){
		return jokes;
	}
	
	public Jokes(){
        String language = Locale.getDefault().getLanguage();
        try{
            list.put(JokeCategory.computerLost, readFile(getFileName("computerlost.txt", language)));
            list.put(JokeCategory.computerWon, readFile(getFileName("computerwon.txt", language)));
            list.put(JokeCategory.drawn, readFile(getFileName("drawn.txt", language)));
        }catch(FileNotFoundException fnfe){
            fnfe.printStackTrace();

        }
	}

    private String getFileName(String baseFileName, String i18n) throws FileNotFoundException{
        String fileName = "./jokes/"+i18n+"/"+baseFileName;
        if(new File(fileName).exists()) return fileName;

        fileName = "./jokes/en/"+baseFileName;
        if(new File(fileName).exists()) return fileName;

        throw new FileNotFoundException("File exists neither in selected locale "+i18n+" nor in locale en: "+baseFileName);
    }
	
	private String[] readFile(String fileName){
		String input;
		try {
			input = ListFile.listFile(fileName);
			return input.split("\n+");
		} catch (IOException e) {
			e.printStackTrace();
		}
		return new String[]{};
	}
	
	
	public String getRandomJoke(JokeCategory cat){
		String[] strs = list.get(cat);
		if(strs == null || strs.length == 0) return Resources.getMessages().getString("error.no.joke.found");
		
		int i = new Random().nextInt(strs.length);
		return strs[i];
	}
	
}
