/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.dialogs;

import klaus.KlausWindow;
import klaus.Resources;
import klaus.Settings;
import klaus.engine.EngineData;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 *
 * @author Stephan Hillebrand
 */
public class NewOfflineGameDialog extends javax.swing.JDialog {

	private NewGameModel model = new NewGameModel();
	
    /** Creates new form newOfflineGameDialog */
    public NewOfflineGameDialog(KlausWindow parent, boolean modal) {
        
        super(parent, modal);
        initComponentsChanged();
        //TODO Make this persistent
        cancel.addActionListener(new ActionListener(){
			public void actionPerformed(@SuppressWarnings("unused")
			ActionEvent e) {
				setVisible(false);
			}  	
        });
        startGame.addActionListener(new ActionListener() {
        	@SuppressWarnings("unused")
			public void actionPerformed(ActionEvent arg0) {
        		model.setStartNewGame(true);
        		model.setBlackEngineName((String)blackEngine.getModel().getSelectedItem());
        		model.setBlackPlayer(blackHuman.isSelected());
        		
        		model.setFirstPeriod((Integer)firstPeriod.getValue() * 60000);
        		model.setFirstPeriodDuration((Integer) firstperiodMove.getValue());
        		model.setSecondPeriod((Integer) secondPeriod.getValue() * 60000);
        		model.setSecondPeriodDuration((Integer) secondPeriodMove.getValue());
        		model.setThirdPeriod((Integer) thirdPeriod.getValue() * 60000);
        		model.setThirdPeriodDuration((Integer) thirdPeriodMove.getValue());
        		model.setIncrement((Integer) increment.getValue()*1000);
        		
        		model.setWhitePlayer(whiteHuman.isSelected());
        		model.setWhiteEngineName((String)whiteEngine.getModel().getSelectedItem());
        		
        		setVisible(false);

                Settings.getSettings().setPersistence("NewOfflineGameDialog/firstPeriod", firstPeriod.getValue().toString());
                Settings.getSettings().setPersistence("NewOfflineGameDialog/firstPeriodMoves",
                        firstperiodMove.getValue().toString());
                Settings.getSettings().setPersistence("NewOfflineGameDialog/secondPeriod", secondPeriod.getValue().toString());
                Settings.getSettings().setPersistence("NewOfflineGameDialog/secondPeriodMoves",
                        secondPeriodMove.getValue().toString());
                Settings.getSettings().setPersistence("NewOfflineGameDialog/thirdPeriod", thirdPeriod.getValue().toString());
                Settings.getSettings().setPersistence("NewOfflineGameDialog/thirdPeriodMoves",
                        thirdPeriodMove.getValue().toString());
                Settings.getSettings().setPersistence("NewOfflineGameDialog/increment", increment.getValue().toString());

			}
        	
        });




        DefaultComboBoxModel blackModel = new DefaultComboBoxModel(),
        	whiteModel = new DefaultComboBoxModel();
        for(EngineData edat: Settings.getSettings().getEngines()){
        	blackModel.addElement(edat.getName());
        	whiteModel.addElement(edat.getName());
        }
        
        whiteEngine.setModel(whiteModel);
        blackEngine.setModel(blackModel);
        
        setTitle(Resources.getMessages().getString("new.local.game"));

        //Get persistence values and set them to the components.
        //This is a bit messy because this dialog was originally created with Netbeans...

        if(Settings.getSettings().getPersistence("NewOfflineGameDialog/isWhitePlayerHuman", "true").equals("true"))
            whiteHuman.setSelected(true);
        else
            whiteComputer.setSelected(true);

        if(Settings.getSettings().getPersistence("NewOfflineGameDialog/isBlackPlayerHuman", "false").equals("true"))
            blackHuman.setSelected(true);
        else
            blackComputer.setSelected(true);

        firstPeriod.setValue(Integer.parseInt(Settings.getSettings().getPersistence("NewOfflineGameDialog/firstPeriod",
                "120")));
        firstperiodMove.setValue(Integer.parseInt(Settings.getSettings().getPersistence("NewOfflineGameDialog/firstPeriodMoves",
                "40")));
        secondPeriod.setValue(Integer.parseInt(Settings.getSettings().getPersistence("NewOfflineGameDialog/secondPeriod",
                "60")));
        secondPeriodMove.setValue(Integer.parseInt(Settings.getSettings().getPersistence("NewOfflineGameDialog/secondPeriodMoves",
                "20")));
        thirdPeriod.setValue(Integer.parseInt(Settings.getSettings().getPersistence("NewOfflineGameDialog/thirdPeriod",
                "30")));
        thirdPeriodMove.setValue(Integer.parseInt(Settings.getSettings().getPersistence("NewOfflineGameDialog/thirdPeriodMoves",
                "0")));
        increment.setValue(Integer.parseInt(Settings.getSettings().getPersistence("NewOfflineGameDialog/increment",
                "0")));
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * This method is called "initComponentsChanged() in order to prevent Netbeans from dropping it.
     */
    @SuppressWarnings("unchecked")
    private void initComponentsChanged() {

        buttonGroup1 = new javax.swing.ButtonGroup();
        buttonGroup2 = new javax.swing.ButtonGroup();
        whitePlayer = new javax.swing.JPanel();
        whiteHuman = new javax.swing.JRadioButton();
        whiteComputer = new javax.swing.JRadioButton();
        whiteEngine = new javax.swing.JComboBox();
        blackPlayer = new javax.swing.JPanel();
        blackHuman = new javax.swing.JRadioButton();
        blackComputer = new javax.swing.JRadioButton();
        blackEngine = new javax.swing.JComboBox();
        time = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        firstPeriod = new javax.swing.JSpinner();
        jLabel2 = new javax.swing.JLabel();
        firstperiodMove = new javax.swing.JSpinner();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        secondPeriod = new javax.swing.JSpinner();
        jLabel5 = new javax.swing.JLabel();
        secondPeriodMove = new javax.swing.JSpinner();
        jLabel6 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        thirdPeriod = new javax.swing.JSpinner();
        jLabel8 = new javax.swing.JLabel();
        thirdPeriodMove = new javax.swing.JSpinner();
        jLabel9 = new javax.swing.JLabel();
        jLabel10 = new javax.swing.JLabel();
        increment = new javax.swing.JSpinner();
        jLabel11 = new javax.swing.JLabel();
        startGame = new javax.swing.JButton();
        cancel = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);

        whitePlayer.setBorder(javax.swing.BorderFactory.createTitledBorder(javax.swing.BorderFactory.createTitledBorder(""), Resources.getMessages().getString("white")));

        buttonGroup1.add(whiteHuman);
        whiteHuman.setText(Resources.getMessages().getString("human"));

        buttonGroup1.add(whiteComputer);
        whiteComputer.setText(Resources.getMessages().getString("computer"));

        whiteEngine.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));

        javax.swing.GroupLayout whitePlayerLayout = new javax.swing.GroupLayout(whitePlayer);
        whitePlayer.setLayout(whitePlayerLayout);
        whitePlayerLayout.setHorizontalGroup(
            whitePlayerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(whitePlayerLayout.createSequentialGroup()
                .addGroup(whitePlayerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(whiteHuman)
                    .addComponent(whiteComputer, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(whiteEngine, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap(268, Short.MAX_VALUE))
        );
        whitePlayerLayout.setVerticalGroup(
            whitePlayerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(whitePlayerLayout.createSequentialGroup()
                .addComponent(whiteHuman)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(whiteComputer)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(whiteEngine, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        blackPlayer.setBorder(javax.swing.BorderFactory.createTitledBorder(javax.swing.BorderFactory.createTitledBorder(""), Resources.getMessages().getString("black")));

        buttonGroup2.add(blackHuman);
        blackHuman.setText(Resources.getMessages().getString("human"));

        buttonGroup2.add(blackComputer);
        blackComputer.setText(Resources.getMessages().getString("computer"));

        blackEngine.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));

        javax.swing.GroupLayout blackPlayerLayout = new javax.swing.GroupLayout(blackPlayer);
        blackPlayer.setLayout(blackPlayerLayout);
        blackPlayerLayout.setHorizontalGroup(
            blackPlayerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(blackPlayerLayout.createSequentialGroup()
                .addGroup(blackPlayerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(blackHuman)
                    .addComponent(blackComputer, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(blackEngine, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap(268, Short.MAX_VALUE))
        );
        blackPlayerLayout.setVerticalGroup(
            blackPlayerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(blackPlayerLayout.createSequentialGroup()
                .addComponent(blackHuman)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(blackComputer)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(blackEngine, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        time.setBorder(javax.swing.BorderFactory.createTitledBorder(Resources.getMessages().getString("time")));

        jLabel1.setText(Resources.getMessages().getString("firstPeriod"));

        firstPeriod.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(120), Integer.valueOf(0), null, Integer.valueOf(1)));

        jLabel2.setText(Resources.getMessages().getString("NewOfflineGameDialog.minutes.for"));

        firstperiodMove.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(40), Integer.valueOf(0), null, Integer.valueOf(1)));

        jLabel3.setText(Resources.getMessages().getString("moves"));

        jLabel4.setText(Resources.getMessages().getString("secondPeriod"));

        secondPeriod.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(60), Integer.valueOf(0), null, Integer.valueOf(1)));

        jLabel5.setText(Resources.getMessages().getString("NewOfflineGameDialog.minutes.for"));

        secondPeriodMove.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(20), Integer.valueOf(0), null, Integer.valueOf(1)));

        jLabel6.setText(Resources.getMessages().getString("moves"));

        jLabel7.setText(Resources.getMessages().getString("thirdPeriod"));

        thirdPeriod.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(0), Integer.valueOf(0), null, Integer.valueOf(1)));

        jLabel8.setText(Resources.getMessages().getString("NewOfflineGameDialog.minutes.for"));

        thirdPeriodMove.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(0), Integer.valueOf(0), null, Integer.valueOf(1)));

        jLabel9.setText(Resources.getMessages().getString("moves"));

        jLabel10.setText(Resources.getMessages().getString("inkrement.per.move"));

        increment.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(0), Integer.valueOf(0), null, Integer.valueOf(1)));

        jLabel11.setText(Resources.getMessages().getString("seconds"));

        javax.swing.GroupLayout timeLayout = new javax.swing.GroupLayout(time);
        time.setLayout(timeLayout);
        timeLayout.setHorizontalGroup(
            timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(timeLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(timeLayout.createSequentialGroup()
                        .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                            .addGroup(timeLayout.createSequentialGroup()
                                .addComponent(jLabel7)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(thirdPeriod))
                            .addGroup(timeLayout.createSequentialGroup()
                                .addComponent(jLabel1)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(firstPeriod, javax.swing.GroupLayout.PREFERRED_SIZE, 55, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(timeLayout.createSequentialGroup()
                                .addComponent(jLabel4)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(secondPeriod)))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                            .addGroup(timeLayout.createSequentialGroup()
                                .addComponent(jLabel8)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(thirdPeriodMove))
                            .addGroup(timeLayout.createSequentialGroup()
                                .addComponent(jLabel2)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(firstperiodMove, javax.swing.GroupLayout.PREFERRED_SIZE, 51, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(timeLayout.createSequentialGroup()
                                .addComponent(jLabel5)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(secondPeriodMove)))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jLabel3)
                            .addComponent(jLabel6)
                            .addComponent(jLabel9)))
                    .addGroup(timeLayout.createSequentialGroup()
                        .addComponent(jLabel10)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(increment, javax.swing.GroupLayout.PREFERRED_SIZE, 53, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel11)))
                .addContainerGap(20, Short.MAX_VALUE))
        );
        timeLayout.setVerticalGroup(
            timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(timeLayout.createSequentialGroup()
                .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel1)
                    .addComponent(firstPeriod, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel2)
                    .addComponent(firstperiodMove, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel3))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel4)
                    .addComponent(secondPeriod, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel5)
                    .addComponent(secondPeriodMove, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel6))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel7)
                    .addComponent(thirdPeriod, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel8)
                    .addComponent(thirdPeriodMove, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel9))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(timeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel10)
                    .addComponent(increment, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel11))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        startGame.setText(Resources.getMessages().getString("start.game"));

        cancel.setText(Resources.getMessages().getString("cancel"));

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(time, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(blackPlayer, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(whitePlayer, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(cancel, javax.swing.GroupLayout.DEFAULT_SIZE, 162, Short.MAX_VALUE)
                    .addComponent(startGame, javax.swing.GroupLayout.DEFAULT_SIZE, 162, Short.MAX_VALUE))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(startGame)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(cancel))
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(whitePlayer, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(blackPlayer, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(time, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addContainerGap())
        );

        pack();
    }

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JRadioButton blackComputer;
    private javax.swing.JComboBox blackEngine;
    private javax.swing.JRadioButton blackHuman;
    private javax.swing.JPanel blackPlayer;
    private javax.swing.ButtonGroup buttonGroup1;
    private javax.swing.ButtonGroup buttonGroup2;
    private javax.swing.JButton cancel;
    private javax.swing.JSpinner firstPeriod;
    private javax.swing.JSpinner firstperiodMove;
    private javax.swing.JSpinner increment;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JSpinner secondPeriod;
    private javax.swing.JSpinner secondPeriodMove;
    private javax.swing.JButton startGame;
    private javax.swing.JSpinner thirdPeriod;
    private javax.swing.JSpinner thirdPeriodMove;
    private javax.swing.JPanel time;
    private javax.swing.JRadioButton whiteComputer;
    private javax.swing.JComboBox whiteEngine;
    private javax.swing.JRadioButton whiteHuman;
    private javax.swing.JPanel whitePlayer;
    // End of variables declaration//GEN-END:variables

	public NewGameModel getModel() {
		return model;
	}

}
