/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.engine;

import klaus.Resources;

import java.text.MessageFormat;import java.util.ResourceBundle;

public class DebuggingInformation {
	private String score;
	private int time;
	private int ply;
	private String pv;
	private int nodes;

	/**
	 * Create debugging information from a normal XBoard debugging String.
	 * See XBoard / WinBoard documentation for details.
	 * @param ply the current search depth in half moves
	 * @param score the current score in centipawns
	 * @param time the search time in centiseconds
	 * @param nodes the number of nodes searched
	 * @param pv a String to describe the current main variant
	 */
	public DebuggingInformation(int ply, String score, int time, int nodes, String pv){
		this.ply = ply;
		this.score = score;
		this.time = time;
		this.nodes = nodes;
		this.pv = pv;
		
	}

	public int getNodes() {
		return nodes;
	}

	public int getPly() {
		return ply;
	}

	public String getPv() {
		return pv;
	}

	public String getScore() {
		return score;
	}

	public int getTime() {
		return time;
	}

	public void setNodes(int nodes) {
		this.nodes = nodes;
	}

	public void setPly(int ply) {
		this.ply = ply;
	}

	public void setPv(String pv) {
		this.pv = pv;
	}

	public void setScore(String score) {
		this.score = score;
	}

	public void setTime(int time) {
		this.time = time;
	}

	public String getDescription() {
        ResourceBundle resourceBundle = Resources.getMessages();
		return MessageFormat.format(resourceBundle.getString("html.h3.0.h3.score.1.depth.2.time.3.nodes.4.html"), getPv(), getScore(), getPly(), getTime(), getNodes());
	}
}
