/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.engine;

import klaus.backend.MoveListener;
import klaus.chess.Move;
import klaus.chess.party.Party;

import java.util.Vector;

public abstract class Engine {

	protected Party party = new Party();
	
	public void addMove(Move move){
		party.addMove(move);
	}
	
	public abstract void startCalculation();

	public abstract void cancel();
	
	public abstract void unload();
	
	protected Vector<MoveListener> moveListeners = new Vector<MoveListener>();	
	public void addMoveListener(MoveListener listener){
		moveListeners.add(listener);
	}
	public void removeMoveListener(MoveListener listener){
		moveListeners.remove(listener);
	}
	
	protected void fireMoveListeners(Move move){
		for(MoveListener listener: moveListeners)
			listener.moveDone(move);
	}
	public void removeAllMoveListeners(){
		moveListeners.clear();
	}
	
	protected Vector<DebuggingListener> debuggingListeners = new Vector<DebuggingListener>();
	public void addDebuggingListener(DebuggingListener listener){
		debuggingListeners.add(listener);
	}
	public void removeDebuggingListener(DebuggingListener listener){
		debuggingListeners.remove(listener);
	}
	public void fireDebuggingListeners(DebuggingInformation info){
		for(DebuggingListener listener: debuggingListeners)
			listener.debuggingReceived(info);
	}
	public void clearDebuggingListeners(){
		for(DebuggingListener listener: debuggingListeners)
			listener.newMove();
	}

	public abstract void forceMove();

    /**
     * <p>Set the time model, equivalent to XBoards "level" command.</p>
     * <p>This method should be called in two situations:</p>
     * <ul>
     * <li>A new game was started: Set the time model, timeInMinutes is the
     * time each player has for the first period.
     * <li>A new period just started: set the new time AFTER the time was added to each player's clock.  In this case,
     * timeInMinutes is the old value + the time added
     * </ul>
     * @param timeInMinutes the time for this period
     * @param moves the number of moves to the next period
     * @param increment the increment per move (Fischer clock) (in seconds)                  
     */
    public abstract void setTimeModel(int timeInMinutes, int moves, int increment);
}
