/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.fs;

import java.io.*;

/**
 * This class reads a PGN file without using a database key.
 * @author Stephan Hillebrand
 * @since 2009-03-?? alpha2
 */
public class PGNStreamReader {
//	private BufferedReader reader;
	
	private RandomAccessFile file = null;
	private long lastLinePosition = -1;
	
	/**
	 * Create a new PGN file
	 * @param pgnFile the file to read
	 * @throws FileNotFoundException if the file does not exist
	 */
	public PGNStreamReader(File pgnFile) throws FileNotFoundException {
		file = new RandomAccessFile(pgnFile, "rw");
		
	}
	
	/**
	 * Go to a certain pointer in the file
	 * @param target
	 * @throws IOException
	 */
	public void goTo(long target) throws IOException {
		file.seek(target);
	}
	/**
	 * Gets  the next party. If you want a certain game, specify the game's starting position using
	 * goTo(long) first, and then call getNextParty().
	 * @return a String containing the party, including all meta data.
	 * @throws IOException if the file could not be read
	 * @throws EOFException if no more parties are contained
	 */
	public String getNextParty() throws IOException, EOFException {
		StringBuilder builder = new StringBuilder();
		
		String v = "";
		int cnt = 0;
		while(!(builder.toString().matches(".*[0-2]\n{2,}"))){
//			++count;
			v = file.readLine();
			if(v == null) break;
			lastLinePosition += v.length();
			if(v.equals("")) ++cnt;
			if(cnt == 2) break;
			builder.append(v+"\n");
//			++lastLinePosition;
		}
		
		String text = builder.toString();
		if(text == null || text.equals("null") || text.matches("\\s*")){
			throw new EOFException("No more PGN parties found!");
		}
		return text;
	}

	public long getLastLinePosition() throws IOException {
		return file.getFilePointer();
	}
}
