/*
 * Klaus chess program
 * Copyright (C) 2009 Stephan Hillebrand <stefh123@yahoo.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package klaus.tools;

import klaus.components.ImageCache;

import javax.imageio.ImageIO;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
public class ImageGen {
	public static void main(String[] args){
		if(args.length != 3)
			System.out.println("Usage: klauscreateboard <dark square> <light square> <output>");
		
		BufferedImage light = ImageCache.getImage(new File(args[1]).getAbsolutePath());
		BufferedImage dark = ImageCache.getImage(new File(args[0]).getAbsolutePath());
		
		BufferedImage image = new BufferedImage(light.getWidth() * 10, light.getWidth() * 10,
				BufferedImage.TYPE_4BYTE_ABGR);
		
		Graphics g = image.getGraphics();
		
		Color bg = new Color(255, 0,0,0);
		g.setColor(bg);
		g.fillRect(0, 0,image.getWidth(),image.getHeight());
		
		for(int i = 1; i < 9; i++){
			for(int j = 1; j < 9; j++){
				BufferedImage temp = light;
				if(i % 2 == j % 2)
					temp = dark;
				g.drawImage(temp, i*temp.getWidth(), j*temp.getWidth(), temp.getWidth(), temp.getWidth(), null);

			}
		}
		
		try {
			ImageIO.write(image, "png", new File(args[2]));
			System.out.println("Board file created successfully.");
		} catch (IOException e) {
			e.printStackTrace();
			System.err.println("Failed to create board image file.");
		}
		
	}
}
