package klaus.views;

import klaus.Resources;
import klaus.backend.AnalyzeBackend;
import klaus.backend.ChessBackend;
import klaus.backend.MoveListener;
import klaus.backend.NullBackend;
import klaus.chess.Move;
import klaus.chess.party.Party;
import klaus.components.AnalyzeEngineViewer;
import klaus.components.AnalyzingToolbar;
import klaus.components.ChessBoard;
import klaus.components.NotationViewer;

import javax.swing.*;
import java.awt.*;
import java.text.MessageFormat;

public class AnalyzeView extends View implements ChessView {
	private Party party = null;
	private AnalyzeBackend backend = null;
	
	private NotationViewer notation = null;
	private AnalyzeEngineViewer engine = null;
	private ChessBoard board = null;
	private AnalyzingToolbar toolbar = null;
	
	public AnalyzeView(Party p) {
		this.party = p;
		board = new ChessBoard(new NullBackend());
		
		setLayout(new BorderLayout());
		
		JSplitPane boardToSidepane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT);
		
		JSplitPane boardToAnalyzeArea = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
		boardToSidepane.setLeftComponent(boardToAnalyzeArea);
		
		backend = new AnalyzeBackend();
		backend.setParty(party);
		
		board = new ChessBoard(backend);
		boardToAnalyzeArea.setTopComponent(board);
		board.setMinimumSize(new Dimension(250,250));
		board.setPreferredSize(new Dimension(500,500));
		
		notation = new NotationViewer();
		notation.refresh(party);
		boardToSidepane.setRightComponent(notation);
		boardToSidepane.setDividerLocation(500);
		
		engine = new AnalyzeEngineViewer();
		boardToAnalyzeArea.setBottomComponent(engine);
		boardToAnalyzeArea.setDividerLocation(500);
		
		add(boardToSidepane, BorderLayout.CENTER);
		
		toolbar = new AnalyzingToolbar(this);
		add(toolbar, BorderLayout.NORTH);
		
		backend.addMoveListener(new MoveListener(){
			public void moveDone(@SuppressWarnings("unused")
			Move move) {
				notation.refresh(party);
			}
		});
	}
	
	
	@Override
	public String getDescription() {
		return MessageFormat.format(Resources.getMessages().getString("0.1.analysis"), party.getWhitePlayer(), party.getBlackPlayer());
	}


	public ChessBackend getBackend() {
		return backend;
	}
}
