package klaus.views;

import klaus.KlausWindow;
import klaus.Resources;
import klaus.chess.party.Party;
import klaus.fs.PGNStreamReader;
import myutils.ListFile;
import myutils.components.StatusBar;

import javax.swing.*;
import javax.swing.table.DefaultTableModel;
import java.awt.*;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintStream;
import java.text.MessageFormat;
import java.util.ResourceBundle;


/**
 * A view for showing a PNG database file
 * @author Stephan Hillebrand
 * @since 2009-03-19 alpha2
 */
public class BaseView extends View {
	private String baseFileName = "";

	private KlausWindow parent = null;	
	private JTable games;
	private DefaultTableModel tableModel;
	private StatusBar bar = null;
	
//	private ArrayList<String> parties = new ArrayList<String>();
	private int[] partyPositions;
	private PGNStreamReader content = null;
	
	private boolean ready = false;
	
	
	public BaseView(KlausWindow window, final File selectedFile) {
		this.parent = window;
		baseFileName = selectedFile.getName();

        final ResourceBundle resourceBundle = Resources.getMessages();
		
		tableModel = new DefaultTableModel(){
			@Override
			public boolean isCellEditable(@SuppressWarnings("unused")
			int arg0, @SuppressWarnings("unused")
			int arg1) {
				return false;
			}
		};
		tableModel.addColumn(resourceBundle.getString("id"));
		tableModel.addColumn(resourceBundle.getString("white"));
		tableModel.addColumn(resourceBundle.getString("black"));
		tableModel.addColumn(resourceBundle.getString("result"));
		tableModel.addColumn(resourceBundle.getString("tournament"));
		tableModel.addColumn(resourceBundle.getString("date"));
		tableModel.addColumn(resourceBundle.getString("location"));
		tableModel.addColumn(resourceBundle.getString("ecocode"));
		
		try {
			content = new PGNStreamReader(selectedFile);
		} catch (FileNotFoundException e1) {
			e1.printStackTrace();
			JOptionPane.showMessageDialog(null,
                    resourceBundle.getString("could.not.read.database"),
                    resourceBundle.getString("severe.error"),
					JOptionPane.ERROR_MESSAGE
			);
		}
		
		games = new JTable(tableModel);
		games.addMouseListener(new MouseAdapter(){
			@Override
			public void mouseClicked(MouseEvent e) {
				if(e.getClickCount() == 2){
					int row = games.getSelectedRow();
					int game = Integer.parseInt(tableModel.getValueAt(row, 0).toString());
					String party = "";
					try {
						
						System.out.println("BaseView$1#mouseClicked(MouseEvent): Party starts at "+partyPositions[game]);
						content.goTo(partyPositions[game]);
						party = content.getNextParty();
					} catch (IOException e1) {
						JOptionPane.showMessageDialog(null, resourceBundle.getString("could.not.load.party.database.index.might.be.corrupt"),
                                resourceBundle.getString("database.error"), JOptionPane.ERROR_MESSAGE);
						e1.printStackTrace();
					}
					Party p = new Party();
					p.parsePGN(party);
					AnalyzeView view = new AnalyzeView(p);
					
					parent.addView(view);
				}
			}
		});
	
		setLayout(new BorderLayout());
		
		JScrollPane scroller = new JScrollPane();
		scroller.add(games);
		scroller.getViewport().add(games);
		add(scroller, BorderLayout.CENTER);
		
		bar = new StatusBar(new String[]{
                MessageFormat.format(resourceBundle.getString("0.parties.found"), 0),
                MessageFormat.format(resourceBundle.getString("file.0"), baseFileName),
                resourceBundle.getString("loading")
		});
		add(bar, BorderLayout.SOUTH);
		new Thread(){
			@Override
			public void run(){
				File keyFile = new File(selectedFile.getParentFile().getAbsolutePath()+"/"
						+selectedFile.getName()+".kkf");
				System.out.println("BaseView:              Looking for key at "+keyFile);
				
				
				if(!keyFile.exists()){
					System.out.println("BaseView:              Key not found!");
					int possibility = 
						JOptionPane.showConfirmDialog(null, resourceBundle.getString("no.database.key.found.formatted.dialog"),
                                resourceBundle.getString("database.error"),
								JOptionPane.YES_NO_CANCEL_OPTION, 
								JOptionPane.ERROR_MESSAGE);
					
					boolean createIndex = false;
					if(possibility == JOptionPane.YES_OPTION) createIndex = true;
					else if(possibility == JOptionPane.CANCEL_OPTION) return;
					PrintStream print = null;
					try {
						print = new PrintStream(keyFile);
					} catch (FileNotFoundException e2) {
						System.err.println("Exception: Could not create kkf file!");
					}
					
					if(createIndex){
						print.println("STATUS:"+System.currentTimeMillis());
						print.println("[PARTY INDEX STARTED]");
					}
					
					
					
	//				bar.setMinimum(0);
	//				bar.setMaximum(games.length - 1);
					
					int c = 0;
					while(true){
						String p;
						try {
							p = content.getNextParty();
						} catch (Exception e) {
							
							e.printStackTrace();
							break;
						}
						//Add the missing [ which might be cut off by the stream reader
						p = p.startsWith("[")?p:"["+p;
	//					parties.add(p);
						
						String whitePlayer = "", blackPlayer = "", 
						result = "", site = "", event = "", date = "", eco = "";
						
						for(String data: p.split("\n+")){
							if(data.matches("\\s*\\[White \".+\"\\s*\\]")){
								whitePlayer = (data.split("\"")[1]);
							}
							else if(data.matches("\\s*\\[Black \".+\"\\s*\\]")){
								blackPlayer = (data.split("\"")[1]);
							}
							else if(data.matches("\\s*\\[Result \".+\"\\s*\\]")){
								result = (data.split("\"")[1]);
							}
							else if(data.matches("\\s*\\[Site \".+\"\\s*\\]")){
								site = (data.split("\"")[1]);
							}
							else if(data.matches("\\s*\\[Date \".+\"\\s*\\]")){
								date = (data.split("\"")[1]);
							}
							else if(data.matches("\\s*\\[Event \".+\"\\s*\\]")){
								event = (data.split("\"")[1]);
							}
							else if(data.matches("\\s*\\[ECO \".+\"\\s*\\]")){
								eco = (data.split("\"")[1]);
							}
						}
							
						//Add it to the table model, if no key is read, this will be ignored!
						if(!createIndex){
							tableModel.addRow(new Object[]{
								c,
								whitePlayer,
								blackPlayer,
								result,
								event,
								date,
								site,
								eco
							});
						}
						else{
							try {
								print.println(c+";"+whitePlayer+";"+blackPlayer+";"+result+";"+event+";"+date
										+";"+site+";"+eco+";"+content.getLastLinePosition());
							} catch (IOException e) {
								e.printStackTrace();
							}
						}
						if(++c % 20 == 0) {
							refreshStatusBar(c);
						}
					}
					
					if(createIndex){
						System.out.println("Finishing index creation");
						print.println("[PARTY INDEX FINISHED]");
						print.flush();
						print.close();
						run();
						return;
					}
					ready = true;
					refreshStatusBar(tableModel.getRowCount());
				}else{
					try{
						boolean parties = false;
						String[] vals = ListFile.listFile(keyFile.getAbsolutePath()).split("\n");
						
						partyPositions = new int[vals.length];
						
						int c = 0;
						for(String val: vals){
							
							if(val.equals("[PARTY INDEX STARTED]"))
								parties = true;
							else if(val.equals("[PARTY INDEX FINISHED]"))
								parties = false;
							
							else if(parties){
								String[] inf = val.split(";");
								if(inf.length < 9){
									System.out.println("Line invalid, skipping!");
									continue;
								}
								
								tableModel.addRow(new Object[]{
										inf[0],
										inf[1],
										inf[2],
										inf[3],
										inf[4],
										inf[5],
										inf[6],
										inf[7]
								});
								partyPositions[++c] = Integer.parseInt(inf[8]);
							}
						}
						ready = true;
						refreshStatusBar(tableModel.getRowCount());
					}catch(Exception e){
						e.printStackTrace();
						return;
					}
				}
			}
		}.start();
	}

	private void refreshStatusBar(int c){
		bar.setText(0, MessageFormat.format(Resources.getMessages().getString("0.parties.found"), c));
		bar.setText(2, ready  ? Resources.getMessages().getString("ready"): Resources.getMessages().getString("loading"));
	}
	
	@Override
	public String getDescription() {
		return MessageFormat.format(Resources.getMessages().getString("0.pgn.database"), baseFileName);
	}
}
