
package klaus.views;

import klaus.Resources;
import klaus.Settings;
import klaus.components.EngineCellRenderer;
import klaus.components.GenericSettingsPanel;
import klaus.dialogs.EngineDialog;
import klaus.engine.EngineData;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.MessageFormat;import java.util.ResourceBundle;

/**
 * This is a view for changing the software's settings.
 * @author Stephan Hillebrand
 * @since 2009-03-14 (alpha2)
 */
public class ConfigurationView extends View implements ActionListener {
	private static boolean optionsShown = false;
	
	private GenericSettingsPanel generics = null;
	/**
	 * If this is not an active configuration view but just an error message, 
	 * this is false. So optionsShown will not be reset when this view is closed.
	 */
	private boolean activeConfiguration = true;
	
	private JButton cancel;
	private JButton accept;
	private JButton ok;

	private JButton create;

	private JButton remove;

	private JButton edit;
	private JButton setDefault;

	private DefaultListModel engineModel;

	private JList engineList;
	
	public ConfigurationView(){
        ResourceBundle resourceBundle = Resources.getMessages();
		if(ConfigurationView.optionsShown){
			JLabel errmsg = new JLabel(resourceBundle.getString("settings.already.displayed.formatted"));
			errmsg.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, 18));
			setLayout(new BorderLayout());
			add(errmsg, BorderLayout.CENTER);
			
			activeConfiguration = false;
			
			return;
		}
		
		ConfigurationView.optionsShown = true;
		
		
		setLayout(new BorderLayout());
		
		JLabel caption = new JLabel(resourceBundle.getString("settings.description.formatted"));
		caption.setBackground(Color.WHITE);
		add(caption, BorderLayout.NORTH);
		
		JTabbedPane tabber = new JTabbedPane();
		tabber.setTabPlacement(SwingConstants.LEFT);
		
		add(tabber);
		
		
		generics = new GenericSettingsPanel();
		
		
		tabber.addTab(resourceBundle.getString("general"), generics);
			
		JPanel engines = new JPanel();
		engines.setLayout(new BorderLayout());
		tabber.addTab(resourceBundle.getString("engines"), engines);
		
			JLabel engineDescription = new JLabel(resourceBundle.getString("engine.description.formatted"));
			engines.add(engineDescription, BorderLayout.NORTH);
		
			//Create the data model for the engine
			
			engineList = new JList();
			engineList.setCellRenderer(new EngineCellRenderer());
			refreshList();
			
			JScrollPane scroller = new JScrollPane();
			scroller.add(engineList);
			scroller.getViewport().add(engineList);
			engines.add(scroller, BorderLayout.CENTER);
			
			JPanel engineButtons = new JPanel();
			engineButtons.setLayout(new BorderLayout());
			
			JPanel engineButtonsL = new JPanel(new FlowLayout(FlowLayout.LEFT));
			setDefault = new JButton(resourceBundle.getString("set.as.default.engine"));
			engineButtonsL.add(setDefault);
			setDefault.addActionListener(this);
			engineButtons.add(engineButtonsL, BorderLayout.WEST);
			
			JPanel engineButtonsR = new JPanel();
			engineButtonsR.setLayout(new FlowLayout(FlowLayout.RIGHT));
			
				create = new JButton(resourceBundle.getString("add"));
				engineButtonsR.add(create);
				create.addActionListener(this);
				
				remove = new JButton(resourceBundle.getString("delete"));
				engineButtonsR.add(remove);
				remove.addActionListener(this);
				
				edit = new JButton(resourceBundle.getString("edit"));
				engineButtonsR.add(edit);
				edit.addActionListener(this);
				
			engineButtons.add(engineButtonsR, BorderLayout.EAST);
			engines.add(engineButtons, BorderLayout.SOUTH);
		
		
			
			
		JPanel buttons = new JPanel();	
		buttons.setLayout(new FlowLayout(FlowLayout.RIGHT));
		
			cancel = new JButton(resourceBundle.getString("cancel"));
			buttons.add(cancel);
			cancel.addActionListener(this);
			
			accept = new JButton(resourceBundle.getString("accept"));
			buttons.add(accept);
			accept.addActionListener(this);
			
			ok = new JButton(resourceBundle.getString("ok"));
			buttons.add(ok);
			ok.addActionListener(this);
			
		add(buttons, BorderLayout.SOUTH);
		
		
	}
	@Override
	public boolean closeView(){
        //Ask user if he really wants to close
        if(activeConfiguration){
            ResourceBundle resourceBundle = Resources.getMessages();
            int option = JOptionPane.showConfirmDialog(null, resourceBundle.getString("do.you.want.to.save.your.settings.before.closing"),
                    resourceBundle.getString("warning"), JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.WARNING_MESSAGE);
            if(option == JOptionPane.CANCEL_OPTION) return false;
            if(option == JOptionPane.YES_OPTION) save();
        }

		super.closeView();
		if(activeConfiguration)
			ConfigurationView.optionsShown = false;
		
		return true;
	}
	
	@Override
	public String getDescription(){
		return Resources.getMessages().getString("configuration");
	}
	
	private void save(){
		Settings.getSettings().setLayoutName(generics.getLayoutName());
		Settings.getSettings().setUsername(generics.getUsername());
	}
	public void quit(boolean ask){
        ResourceBundle resourceBundle = Resources.getMessages();
		if(!ask || JOptionPane.showConfirmDialog(this,
                resourceBundle.getString("close.config.without.saving"), resourceBundle.getString("confirm"),
				JOptionPane.YES_NO_OPTION,
				JOptionPane.QUESTION_MESSAGE) == JOptionPane.YES_OPTION){
			
//			
//			//Force a settings reload in order to prevent the changed settings from being saved
//			try{
//				Settings.getSettings().refreshConfig();
//			}catch(Exception e){
//				e.printStackTrace();
//				int val = JOptionPane.showConfirmDialog(null, 
//						"Beim Lesen der Konfiguration trat ein Fehler auf. " +
//						"Dieser Fehler kann zu schwerwiegenden\nFehlern in Ihrer Konfiguration führen." +
//						"Sicherheitshalber sollten\nSie das Programm beenden und versuchen, die Konfiguration " +
//						"von Hand zu reparieren oder\ndie Konfigurationsdatei umbenennen und eine neue " +
//						"Konfiguration\nerstellen zu lassen.\nMöchten Sie das Programm jetzt beenden?", 
//						"Schwerwiegender Fehler", JOptionPane.YES_NO_OPTION, JOptionPane.ERROR_MESSAGE);
//				
//				if(val == JOptionPane.YES_OPTION) System.exit(1);
//			}
			closeView();
			
		}
	}
	
	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == ok){
			save();
			quit(false);
		}
		else if(e.getSource() == cancel)
			quit(true);
		else if(e.getSource() == accept)
			save();
		
		else if(e.getSource() == remove){
            ResourceBundle resourceBundle = Resources.getMessages();
			if(JOptionPane.showConfirmDialog(this, resourceBundle.getString("really.drop.engine"),
                    resourceBundle.getString("confirm"),JOptionPane.YES_NO_OPTION,
					JOptionPane.WARNING_MESSAGE) == JOptionPane.YES_OPTION){
				
				Settings.getSettings().dropEngine((EngineData) engineList.getSelectedValue());
				System.out.println("Success!");
				
				refreshList();
			}
		}
		
		else if(e.getSource() == create){
			EngineData data = EngineDialog.showDlg();
			if(data == EngineData.NO_ENGINE) return;
			
			Settings.getSettings().addEngine(data);
			
			
			refreshList();
		}
		
		else if(e.getSource() == edit){
			System.out.println("Edit mode entered");
			EngineData old = (EngineData) engineList.getSelectedValue();
			EngineData data = EngineDialog.showDlg(old);
			if(data == EngineData.NO_ENGINE) return;
			
			Settings.getSettings().replaceEngine(old, data);
			
			refreshList();
		}
		
		else if(e.getSource() == setDefault){
			System.out.println("EngineSettingsPanel: Changed default");
			Settings.getSettings().setDefaultEngine((EngineData)engineList.getSelectedValue());
			
			refreshList();
		}
		
	}
	private void refreshList() {
		engineModel = new DefaultListModel();
		for(EngineData engine: Settings.getSettings().getEngines())
			engineModel.addElement(engine);
		
		engineList.setModel(engineModel);
	}
}
