package klaus.views;

import klaus.Resources;
import klaus.components.ICSChannelChatMainPanel;
import klaus.components.ICSPrivateChatMainPanel;
import klaus.components.ICSTerminal;
import klaus.cs.KlausFreechessConnection;

import javax.swing.*;
import java.awt.*;

/**
 * A view for chatting and overview on ICS's
 * @author Stephan Hillebrand
 *
 */
public class ICSView extends View {
	private String uname, pwd, host;
	
	private KlausFreechessConnection server = null;
	
	private boolean running = true;
	
	private ICSView me = this;
	
	/**
	 * The panel containing channel chats
	 */
	private ICSChannelChatMainPanel channels;
	/**
	 * The panel containing tells
	 */
	private ICSPrivateChatMainPanel tells;
	/**
	 * the terminal / console
	 */
	private ICSTerminal terminal;
	
	public ICSView(final String uname,final String pwd,final String host,final int port){
		System.out.println("ICS View set up");
		this.uname = uname;
		this.pwd = pwd;
		this.host = host;
		
		server = new KlausFreechessConnection(uname, pwd, me);
		
		new Thread(){
			public void run(){

				
				server.initiateConnect(host, port);
				while(!server.isConnected()){
					Thread.yield();
				}
				System.out.println("Connection set up.");
				server.initiateLogin();
//				
//				while(!(server.isLoggedIn() || ){
//					System.out.println("Not logged in!");
//					Thread.yield();
//				}
//				
//				System.out.println("Logged in successful, setting up main loop ");
//				
//				while(running){
//					// I suppose this loop is completely unnecessary, but maybe
//					// something has to be done during clean-up
//					break;
//				}
				
			}
		}.start();
		
		//Set up views
		setLayout(new BorderLayout());
		JSplitPane topToBottom = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
		JSplitPane bottom = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT);
		
		// Create a babasChess-like component orientation
		terminal = new ICSTerminal(server);
		bottom.setLeftComponent(terminal);
		
		tells = new ICSPrivateChatMainPanel();
		bottom.setRightComponent(tells);
		
		
		channels = new ICSChannelChatMainPanel(server);
		topToBottom.setTopComponent(channels);
		topToBottom.setBottomComponent(bottom);
		
		add(topToBottom, BorderLayout.CENTER);
		
		bottom.setResizeWeight(0.4);
		topToBottom.setResizeWeight(0.7);
	}
	
	@Override
	public String getName() {
//		if(server == null || (!server.isConnected()) || (!server.isLoggedIn()))
//			return "Verbinde: "+host;
//		return server.getUsername()+"@"+server.getHost();
		return Resources.getMessages().getString("ics.main.window");
		
	}

	/**
	 * Dispatch a channel tell to the fitting window
	 * @param username
	 * @param titles
	 * @param channelNumber
	 * @param message
	 */
	public void dispatchChannelTell(String username, String titles,
			int channelNumber, String message) {
		channels.addMessage(channelNumber, username, titles, message);
	}
	
	/**
	 * Dispatch method for anything (printing line to console)
	 * @param message the message received from server
	 */
	public void dispatchAnything(String message){
//		System.out.println("term mess "+message);
		terminal.addLine(message);
	}
	
}
