package klaus.views;

import klaus.Error;
import klaus.KlausWindow;
import klaus.Resources;
import klaus.Settings;
import klaus.components.ImageCache;
import klaus.dialogs.NewGameModel;
import myutils.components.StatusBar;

import javax.swing.*;
import java.awt.*;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionAdapter;
import java.io.File;
import java.text.MessageFormat;import java.util.ResourceBundle;

public class WelcomeView extends View {
	private StatusBar bar = new StatusBar(new String[]{""});
	private KlausWindow window = null;

    private ResourceBundle resourceBundle = Resources.getMessages();
	
	public WelcomeView(KlausWindow win){
		window = win;
		setLayout(new BorderLayout());
		add(bar, BorderLayout.SOUTH);
		
		addMouseMotionListener(new MouseMotionAdapter(){
			@Override
			public void mouseMoved(MouseEvent e) {
				if(new Rectangle(200,80,600,128).contains(e.getPoint()))
					bar.setText(0, resourceBundle.getString("new.game.vs.computer"));
				else if(new Rectangle(0, 230, 600, 128).contains(e.getPoint()))
					bar.setText(0, resourceBundle.getString("open.klaus.website"));
			}
		});
		
		addMouseListener(new MouseAdapter(){
			@Override
			public void mouseClicked(MouseEvent e) {
				if(new Rectangle(200,80,600,128).contains(e.getPoint())){
					
					//Need a default engine first!
					if(Settings.getSettings().getDefaultEngine().equals(Error.ERROR_0001_NO_DEFAULT_ENGINE)){
						JOptionPane.showMessageDialog(null, resourceBundle.getString("need.to.set.a.default.engine"), resourceBundle.getString("no.default.engine"), JOptionPane.INFORMATION_MESSAGE);
						return;
					}
					
					NewGameModel model = new NewGameModel();
					
					
					PlayingView view = new PlayingView();
					view.getParty().setWhitePlayer(Settings.getSettings().getUsername());
					
					view.getParty().setBlackPlayer(Settings.getSettings().getEngines()[0].getName());
					view.setBlackEngineName(model.getBlackEngineName());
					
					view.setGameModel(model);
					
					window.addView(view);
				}
				else if(new Rectangle(0, 230, 600, 128).contains(e.getPoint()))
					JOptionPane.showMessageDialog(null, resourceBundle.getString("not.supported.in.this.klaus.version"), resourceBundle.getString("error"), JOptionPane.ERROR_MESSAGE);
			}
		});
		
		setMinimumSize(new Dimension(600, 600));
	}
	
	
	@Override
	public void paintComponent(Graphics g){
		g.drawImage(ImageCache.getImage(new File("graphics/welcome/background.png").getAbsolutePath())
				,0,0, getWidth(), getHeight(), null);
		
		g.setColor(Color.YELLOW);
		g.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, 18));
		
		g.drawString(resourceBundle.getString("welcome.to.klaus"), 20, 20);
		
		g.setColor(Color.GREEN);
		g.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, 15));
		
		g.drawString(resourceBundle.getString("an.intuitife.free.chess.program"),
				20,50);
		
		g.setColor(Color.BLACK);
		g.drawString("This program comes with ABSOLUTELY NO WARRANTY; for details see Help" +
				" -> License in the menu.", 25, getHeight()-85);
		g.drawString("This is free software, and you are welcome to redistribute it",
				25, getHeight() - 60);
		g.drawString("under certain conditions; see Help -> License in the menu for details.",
				25, getHeight()-35);
		
		
		g.drawImage(ImageCache.getImage(new File("graphics/welcome/playnow.png").getAbsolutePath()),
				200, 80, 600, 128, null);
		g.drawImage(ImageCache.getImage("graphics/welcome/website.png"), 0, 230, 600, 128, null);
		
	}
	
	@Override
	public String getDescription(){
		return resourceBundle.getString("welcome");
	}
	
}
