package myutils;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.HashMap;
import java.util.Set;


/**
 * Klasse zum Lesen von ini-Dateien
 * @author Stephan Hillebrand
 * @since 0.5
 */
public class INIReader {
    private HashMap<String, String> hash = new HashMap<String, String>();
    
    private String INIFile;
    /**
     * 
     * Konstruktor
     * @param INIFile die INI-Datei, die gelesen wird 
     * @throws IOException Datei existiert nicht oder ist besch�digt
     * @throws IllegalArgumentException Datei ist kein INI-File
     */
    public INIReader(String INIFile) throws IllegalArgumentException, IOException{
        this.INIFile = INIFile;
        if(!INIFile.endsWith(".ini"))
            throw new IllegalArgumentException(INIFile+" ist keine INI-Datei!");
        
        BufferedReader in = new BufferedReader(new FileReader(INIFile));
        
        for (int i = 0;;i++) {
		  String s = in.readLine();
		  if (s!=null){
		      try{
			      String[] read = s.split("=");
//			      System.out.println("L�nge der Zeile: "+read.length+" (normal: 2)");
			      hash.put(read[0], read[1]);

		      }catch(Exception e){
		          e.printStackTrace();
		          throw new IOException("Schaden in INI-File, Zeile "+i+":\n\t"+s);
		      }
		  }
		  else{
		      break;
		  }
        }
    }
    
    /**
     * Sucht einen parameter aus der ini-Datei
     * @param key der zu suchende Parameter
     * @return der wert des parameters
     * @throws ItemNotFoundException wird geworfen, wenn key nicht in der Datei enthalten ist
     */
    public String get(String key) throws ItemNotFoundException{
        Object o = hash.get(key);
        if(o==null)
            throw new ItemNotFoundException("Item "+key+" nicht gefunden!");
        return ((String) o);
    }

    /**
     * Gibt hashtable als String zur�ck
     * @return die Hashtable als String
     */
    public String toString(){
        return "<INIREADER>";
    }
    
    /**
     * F�gt einen neuen String hinzu
     * @param key der Key
     * @param value der Wert
     */
    public void insertString(String key, String value){
        hash.put(key, value);
    }
    
    public void save(){
        BufferedWriter out = null;
        try {
            out = new BufferedWriter(new FileWriter(INIFile));
        } catch (IOException e) {}
//        Collection coll = hash.values();
        Set s = hash.keySet();
        Object[] lines = s.toArray();
        for(int i = 0; i<lines.length;i++){
            String line = (String)lines[i]+"="+(String)(hash.get(lines[i]))+"\n";
            System.out.println(line);
            try {
                out.write(line);
            } catch (IOException e1) {}  
        }
        try{
	        out.flush();
	        out.close();
        }catch(Exception e){}
    }
}